# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/pl_PL/__init__.py

job_formats_ru_ru <- c(
  "\u0410\u0432\u0438\u0430\u0434\u0438\u0441\u043f\u0435\u0442\u0447\u0435\u0440",
  "\u0410\u0432\u0438\u0430\u0442\u0435\u0445\u043d\u0438\u043a",
  "\u0410\u0432\u0438\u0430\u0446\u0438\u043e\u043d\u043d\u044b\u0439 \u0442\u0435\u0445\u043d\u0438\u043a",
  "\u0410\u0432\u0442\u043e\u0433\u043e\u043d\u0449\u0438\u043a",
  "\u0410\u0432\u0442\u043e\u0441\u043b\u0435\u0441\u0430\u0440\u044c",
  "\u0410\u0432\u0442\u043e\u044d\u043b\u0435\u043a\u0442\u0440\u0438\u043a",
  "\u0410\u0433\u0440\u043e\u043d\u043e\u043c",
  "\u0410\u0433\u0440\u043e\u043d\u043e\u043c \u043f\u043e \u0437\u0430\u0449\u0438\u0442\u0435 \u0440\u0430\u0441\u0442\u0435\u043d\u0438\u0439",
  "\u0410\u0433\u0440\u043e\u043d\u043e\u043c-\u043f\u043e\u0447\u0432\u043e\u0432\u0435\u0434",
  "\u0410\u0434\u0432\u043e\u043a\u0430\u0442",
  "\u0410\u0434\u043c\u0438\u043d\u0438\u0441\u0442\u0440\u0430\u0442\u043e\u0440 \u0431\u0430\u0437\u044b \u0434\u0430\u043d\u043d\u044b\u0445",
  "\u0410\u043a\u043a\u0443\u043c\u0443\u043b\u044f\u0442\u043e\u0440\u0449\u0438\u043a",
  "\u0410\u043a\u0442\u0443\u0430\u0440\u0438\u0439",
  "\u0410\u043a\u0442\u0451\u0440",
  "\u0410\u043a\u0443\u0448\u0435\u0440",
  "\u0410\u043b\u043b\u0435\u0440\u0433\u043e\u043b\u043e\u0433",
  "\u0410\u043d\u0430\u043b\u0438\u0442\u0438\u043a",
  "\u0410\u043d\u0434\u0440\u043e\u043b\u043e\u0433",
  "\u0410\u043d\u0442\u0440\u043e\u043f\u043e\u043b\u043e\u0433",
  "\u0410\u0440\u0442\u0438\u043b\u043b\u0435\u0440\u0438\u0441\u0442",
  "\u0410\u0440\u0442\u0438\u0441\u0442 \u0446\u0438\u0440\u043a\u0430",
  "\u0410\u0440\u0445\u0435\u043e\u043b\u043e\u0433",
  "\u0410\u0440\u0445\u0438\u0432\u0430\u0440\u0438\u0443\u0441",
  "\u0410\u0440\u0445\u0438\u0442\u0435\u043a\u0442\u043e\u0440",
  "\u0410\u0441\u0442\u0440\u043e\u043d\u043e\u043c",
  "\u0410\u0441\u0442\u0440\u043e\u0444\u0438\u0437\u0438\u043a",
  "\u0410\u0441\u0442\u0440\u043e\u0445\u0438\u043c\u0438\u043a",
  "\u0411\u0430\u043a\u0442\u0435\u0440\u0438\u043e\u043b\u043e\u0433",
  "\u0411\u0430\u043b\u0435\u0440\u0438\u043d\u0430",
  "\u0411\u0430\u043b\u0435\u0442\u043c\u0435\u0439\u0441\u0442\u0435\u0440",
  "\u0411\u0430\u043d\u043a\u0438\u0440",
  "\u0411\u0430\u0440\u043c\u0435\u043d",
  "\u0411\u0430\u0442\u0430\u043b\u0435\u0440",
  "\u0411\u0435\u0437\u0440\u0430\u0431\u043e\u0442\u043d\u044b\u0439",
  "\u0411\u0438\u0431\u043b\u0438\u043e\u0442\u0435\u043a\u0430\u0440\u044c",
  "\u0411\u0438\u0431\u043b\u0438\u043e\u0442\u0435\u043a\u043e\u0432\u0435\u0434",
  "\u0411\u0438\u043e\u0438\u043d\u0436\u0435\u043d\u0435\u0440",
  "\u0411\u0438\u043e\u043b\u043e\u0433",
  "\u0411\u0438\u043e\u0444\u0438\u0437\u0438\u043a",
  "\u0411\u0438\u043e\u0445\u0438\u043c\u0438\u043a",
  "\u0411\u043b\u043e\u0433\u0433\u0435\u0440",
  "\u0411\u043e\u043d\u0434\u0430\u0440\u044c",
  "\u0411\u043e\u0440\u0442-\u0438\u043d\u0436\u0435\u043d\u0435\u0440",
  "\u0411\u043e\u0440\u0442-\u043c\u0435\u0445\u0430\u043d\u0438\u043a",
  "\u0411\u043e\u0440\u0442-\u0440\u0430\u0434\u0438\u0441\u0442",
  "\u0411\u043e\u0440\u0442-\u0441\u0442\u0440\u0435\u043b\u043e\u043a",
  "\u0411\u043e\u0440\u0442\u0438\u043d\u0436\u0435\u043d\u0435\u0440",
  "\u0411\u043e\u0440\u0442\u043c\u0435\u0445\u0430\u043d\u0438\u043a",
  "\u0411\u043e\u0440\u0442\u043f\u0440\u043e\u0432\u043e\u0434\u043d\u0438\u043a/\u0441\u0442\u044e\u0430\u0440\u0434",
  "\u0411\u043e\u0442\u0430\u043d\u0438\u043a",
  "\u0411\u0440\u0435\u0439\u0434\u0435\u0440",
  "\u0411\u0440\u043e\u043a\u0435\u0440",
  "\u0411\u0443\u043b\u043e\u0447\u043d\u0438\u043a",
  "\u0411\u0443\u043b\u044c\u0434\u043e\u0437\u0435\u0440\u0438\u0441\u0442",
  "\u0411\u0443\u0445\u0433\u0430\u043b\u0442\u0435\u0440",
  "\u0412\u0435\u0431-\u0438\u043d\u0442\u0435\u0433\u0440\u0430\u0442\u043e\u0440",
  "\u0412\u0435\u0431-\u043c\u0430\u0441\u0442\u0435\u0440",
  "\u0412\u0435\u0431-\u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0438\u0441\u0442",
  "\u0412\u0435\u0440\u0441\u0442\u0430\u043b\u044c\u0449\u0438\u043a",
  "\u0412\u0435\u0442\u0435\u0440\u0438\u043d\u0430\u0440",
  "\u0412\u0438\u0437\u0430\u0436\u0438\u0441\u0442",
  "\u0412\u0438\u043d\u043e\u0433\u0440\u0430\u0434\u0430\u0440\u044c",
  "\u0412\u0438\u0440\u0443\u0441\u043e\u043b\u043e\u0433",
  "\u0412\u043e\u0434\u0438\u0442\u0435\u043b\u044c",
  "\u0412\u043e\u0434\u043e\u043b\u0430\u0437",
  "\u0412\u043e\u0435\u043d\u043d\u043e-\u043f\u043e\u043b\u0435\u0432\u043e\u0439 \u0445\u0438\u0440\u0443\u0440\u0433",
  "\u0412\u043e\u0435\u043d\u043d\u043e-\u043f\u043e\u043b\u0435\u0432\u043e\u0439 \u0445\u0438\u0440\u0443\u0440\u0433",
  "\u0412\u043e\u0435\u043d\u043d\u043e\u0441\u043b\u0443\u0436\u0430\u0449\u0438\u0439",
  "\u0412\u043e\u0435\u043d\u043d\u044b\u0439 \u0434\u043e\u0437\u043d\u0430\u0432\u0430\u0442\u0435\u043b\u044c",
  "\u0412\u043e\u0435\u043d\u043d\u044b\u0439 \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u043d\u0442",
  "\u0412\u043e\u0435\u043d\u043d\u044b\u0439 \u043f\u0435\u0440\u0435\u0432\u043e\u0434\u0447\u0438\u043a",
  "\u0412\u043e\u0435\u043d\u043d\u044b\u0439 \u043f\u043e\u043b\u0438\u0446\u0435\u0439\u0441\u043a\u0438\u0439",
  "\u0412\u043e\u0435\u043d\u043d\u044b\u0439 \u043f\u0440\u043e\u043a\u0443\u0440\u043e\u0440",
  "\u0412\u043e\u0435\u043d\u043d\u044b\u0439 \u0441\u0443\u0434\u044c\u044f",
  "\u0412\u043e\u0435\u043d\u043d\u044b\u0439 \u044e\u0440\u0438\u0441\u0442",
  "\u0412\u043e\u0437\u0434\u0443\u0445\u043e\u043f\u043b\u0430\u0432\u0430\u0442\u0435\u043b\u044c",
  "\u0412\u043e\u043a\u0430\u043b\u0438\u0441\u0442",
  "\u0412\u043e\u0441\u043f\u0438\u0442\u0430\u0442\u0435\u043b\u044c",
  "\u0412\u043e\u0441\u043f\u0438\u0442\u0430\u0442\u0435\u043b\u044c",
  "\u0412\u043e\u0441\u0442\u043e\u043a\u043e\u0432\u0435\u0434",
  "\u0412\u0440\u0430\u0447 \u041c\u0421\u042d\u041a",
  "\u0412\u0440\u0430\u0447 \u0423\u0417-\u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u043a\u0438",
  "\u0412\u0440\u0430\u0447 \u0441\u043a\u043e\u0440\u043e\u0439 \u043f\u043e\u043c\u043e\u0449\u0438",
  "\u0412\u0440\u0430\u0447 \u0444\u0443\u043d\u043a\u0446\u0438\u043e\u043d\u0430\u043b\u044c\u043d\u043e\u0439 \u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u043a\u0438",
  "\u0412\u044b\u043f\u0443\u0441\u043a\u0430\u044e\u0449\u0438\u0439 \u0440\u0435\u0434\u0430\u043a\u0442\u043e\u0440",
  "\u0413\u0430\u0441\u0442\u0440\u043e\u044d\u043d\u0442\u0435\u0440\u043e\u043b\u043e\u0433",
  "\u0413\u0435\u043c\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0413\u0435\u043d\u0435\u0442\u0438\u043a",
  "\u0413\u0435\u043d\u0435\u0442\u0438\u043a",
  "\u0413\u0435\u043e\u0433\u0440\u0430\u0444",
  "\u0413\u0435\u043e\u0434\u0435\u0437\u0438\u0441\u0442",
  "\u0413\u0435\u043e\u043b\u043e\u0433",
  "\u0413\u0435\u043f\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0413\u0438\u0434\u0440\u043e\u043b\u043e\u0433",
  "\u0413\u0438\u043d\u0435\u043a\u043e\u043b\u043e\u0433",
  "\u0413\u0438\u0440\u0443\u0434\u043e\u0442\u0435\u0440\u0430\u043f\u0435\u0432\u0442",
  "\u0413\u0438\u0442\u0430\u0440\u0438\u0441\u0442",
  "\u0413\u043b\u044f\u0446\u0438\u043e\u043b\u043e\u0433",
  "\u0413\u043e\u043c\u0435\u043e\u043f\u0430\u0442",
  "\u0413\u043e\u0440\u043d\u0438\u0447\u043d\u0430\u044f",
  "\u0413\u043e\u0440\u043d\u043e\u0441\u0442\u0440\u0435\u043b\u043e\u043a",
  "\u0413\u043e\u0440\u043d\u044f\u043a",
  "\u0413\u043e\u0441\u0443\u0434\u0430\u0440\u0441\u0442\u0432\u0435\u043d\u043d\u044b\u0439 \u0438\u0441\u043f\u043e\u043b\u043d\u0438\u0442\u0435\u043b\u044c",
  "\u0413\u0440\u0430\u043d\u0430\u0442\u043e\u043c\u0451\u0442\u0447\u0438\u043a",
  "\u0413\u0440\u0435\u0439\u0434\u0435\u0440\u0438\u0441\u0442",
  "\u0413\u0440\u0435\u043d\u0430\u0434\u0435\u0440",
  "\u0413\u0440\u0438\u043c\u0435\u0440",
  "\u0413\u0440\u0443\u0437\u0447\u0438\u043a",
  "\u0414\u0432\u043e\u0440\u043d\u0438\u043a",
  "\u0414\u0435\u043a\u0430\u043d",
  "\u0414\u0435\u043a\u043e\u0440\u0430\u0442\u043e\u0440",
  "\u0414\u0435\u0440\u043c\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0414\u0435\u0441\u0430\u043d\u0442\u043d\u0438\u043a",
  "\u0414\u0435\u0442\u0435\u043a\u0442\u0438\u0432",
  "\u0414\u0435\u0444\u0435\u043a\u0442\u043e\u043b\u043e\u0433",
  "\u0414\u0438\u0432\u0435\u0440\u0441\u0430\u043d\u0442",
  "\u0414\u0438\u0434\u0436\u0435\u0439",
  "\u0414\u0438\u0435\u0442\u043e\u043b\u043e\u0433",
  "\u0414\u0438\u0437\u0430\u0439\u043d\u0435\u0440",
  "\u0414\u0438\u0437\u0430\u0439\u043d\u0435\u0440 \u0440\u0435\u043a\u043b\u0430\u043c\u044b",
  "\u0414\u0438\u0437\u0430\u0439\u043d\u0435\u0440-\u043a\u043e\u043d\u0441\u0442\u0440\u0443\u043a\u0442\u043e\u0440",
  "\u0414\u0438\u043a\u0442\u043e\u0440",
  "\u0414\u0438\u043b\u0435\u0440",
  "\u0414\u0438\u043f\u043b\u043e\u043c\u0430\u0442",
  "\u0414\u0438\u043f\u043b\u043e\u043c\u0430\u0442",
  "\u0414\u0438\u043f\u043b\u043e\u043c\u0430\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0439 \u0440\u0430\u0431\u043e\u0442\u043d\u0438\u043a",
  "\u0414\u0438\u0440\u0438\u0436\u0451\u0440",
  "\u0414\u0438\u0441\u043f\u0435\u0442\u0447\u0435\u0440",
  "\u0414\u043e\u0437\u043d\u0430\u0432\u0430\u0442\u0435\u043b\u044c",
  "\u0414\u043e\u043d\u043a\u0435\u0440\u043c\u0430\u043d",
  "\u0414\u043e\u0443\u043b\u0430",
  "\u0414\u043e\u044f\u0440\u043a\u0430",
  "\u0414\u0440\u0430\u043f\u0438\u0440\u043e\u0432\u0449\u0438\u043a",
  "\u0415\u0433\u0438\u043f\u0442\u043e\u043b\u043e\u0433",
  "\u0416\u0438\u0432\u043e\u0442\u043d\u043e\u0432\u043e\u0434",
  "\u0416\u0438\u043b\u043e\u0432\u0449\u0438\u043a/\u041e\u0431\u0432\u0430\u043b\u044c\u0449\u0438\u043a",
  "\u0416\u0443\u0440\u043d\u0430\u043b\u0438\u0441\u0442",
  "\u0417\u0430\u0440\u044f\u0436\u0430\u044e\u0449\u0438\u0439",
  "\u0417\u0430\u0442\u043e\u0447\u043d\u0438\u043a",
  "\u0417\u0432\u0443\u043a\u043e\u0440\u0435\u0436\u0438\u0441\u0441\u0451\u0440",
  "\u0417\u0435\u043d\u0438\u0442\u0447\u0438\u043a",
  "\u0417\u043b\u0430\u0442\u043e\u043a\u0443\u0437\u043d\u0435\u0446",
  "\u0417\u043e\u043e\u043b\u043e\u0433",
  "\u0417\u043e\u043e\u0442\u0435\u0445\u043d\u0438\u043a",
  "\u0418\u0437\u0434\u0430\u0442\u0435\u043b\u044c",
  "\u0418\u0437\u043e\u0431\u0440\u0435\u0442\u0430\u0442\u0440",
  "\u0418\u043a\u043e\u043d\u043e\u043f\u0438\u0441\u0435\u0446",
  "\u0418\u043b\u043b\u044e\u0441\u0442\u0440\u0430\u0442\u043e\u0440",
  "\u0418\u043c\u0438\u0434\u0436\u043c\u0435\u0439\u043a\u0435\u0440",
  "\u0418\u043c\u043c\u0443\u043d\u043e\u043b\u043e\u0433",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440 \u041a\u0418\u041f\u0438\u0410",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440 \u043f\u043e \u0422\u0435\u0445\u043d\u0438\u043a\u0435 \u0411\u0435\u0437\u043e\u043f\u0430\u0441\u043d\u043e\u0441\u0442\u0438",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440 \u043f\u043e \u043c\u0435\u0445\u0430\u043d\u0438\u0437\u0430\u0446\u0438\u0438",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u0430\u043a\u0443\u0441\u0442\u0438\u043a",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u0432\u0437\u0440\u044b\u0432\u043e\u0442\u0435\u0445\u043d\u0438\u043a",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u0433\u0430\u043b\u044c\u0432\u0430\u043d\u0438\u043a",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u0433\u0438\u0434\u0440\u0430\u0432\u043b\u0438\u043a",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u043a\u043e\u043d\u0441\u0442\u0440\u0443\u043a\u0442\u043e\u0440",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u043b\u0430\u0431\u043e\u0440\u0430\u043d\u0442",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u043b\u0435\u0441\u043e\u0442\u0435\u0445\u043d\u0438\u043a",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u043c\u0435\u0445\u0430\u043d\u0438\u043a",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u0441\u0438\u0441\u0442\u0435\u043c\u043e\u0442\u0435\u0445\u043d\u0438\u043a",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u0441\u0442\u0440\u043e\u0438\u0442\u0435\u043b\u044c",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u0442\u0435\u0445\u043d\u043e\u043b\u043e\u0433",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u0444\u0438\u0437\u0438\u043a",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u0445\u0438\u043c\u0438\u043a",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u044d\u043b\u0435\u043a\u0442\u0440\u0438\u043a",
  "\u0418\u043d\u0436\u0435\u043d\u0435\u0440-\u044d\u043d\u0435\u0440\u0433\u0435\u0442\u0438\u043a",
  "\u0418\u043d\u043a\u0430\u0441\u0441\u0430\u0442\u043e\u0440",
  "\u0418\u043d\u0442\u0435\u043d\u0434\u0430\u043d\u0442",
  "\u0418\u043d\u0444\u0435\u043a\u0446\u0438\u043e\u043d\u0438\u0441\u0442",
  "\u0418\u0441\u043a\u0443\u0441\u0441\u0442\u0432\u043e\u0432\u0435\u0434",
  "\u0418\u0441\u0442\u043e\u0440\u0438\u043a",
  "\u0418\u0445\u0442\u0438\u043e\u043b\u043e\u0433",
  "\u041a\u0430\u0431\u0435\u043b\u044c\u0449\u0438\u043a",
  "\u041a\u0430\u0432\u0430\u043b\u0435\u0440\u0438\u0441\u0442",
  "\u041a\u0430\u043c\u0435\u043d\u043e\u0442\u0451\u0441",
  "\u041a\u0430\u043d\u043e\u043d\u0438\u0440",
  "\u041a\u0430\u043f\u0438\u0442\u0430\u043d \u0441\u0443\u0434\u043d\u0430",
  "\u041a\u0430\u043f\u0442\u0435\u043d\u0430\u0440\u043c\u0443\u0441",
  "\u041a\u0430\u0440\u0434\u0438\u043e\u043b\u043e\u0433",
  "\u041a\u0430\u0440\u0434\u0438\u043e\u0445\u0438\u0440\u0443\u0440\u0433",
  "\u041a\u0430\u0441\u043a\u0430\u0434\u0451\u0440",
  "\u041a\u0430\u0441\u0441\u0438\u0440",
  "\u041a\u0432\u0430\u0441\u043d\u0438\u043a",
  "\u041a\u0438\u043d\u043e\u0434\u0440\u0430\u043c\u0430\u0442\u0443\u0440\u0433",
  "\u041a\u0438\u043d\u043e\u043b\u043e\u0433",
  "\u041a\u0438\u043d\u043e\u043b\u043e\u0433",
  "\u041a\u0438\u043d\u043e\u043c\u0435\u0445\u0430\u043d\u0438\u043a",
  "\u041a\u0438\u043d\u043e\u043e\u043f\u0435\u0440\u0430\u0442\u043e\u0440",
  "\u041a\u0438\u043d\u043e\u0440\u0435\u0436\u0438\u0441\u0441\u0435\u0440",
  "\u041a\u043b\u0430\u0434\u043e\u0432\u0449\u0438\u043a",
  "\u041a\u043b\u0438\u043d\u0435\u0440",
  "\u041a\u043d\u043e\u043f\u043e\u0447\u043d\u0438\u043a",
  "\u041a\u043e\u0434\u0435\u0440",
  "\u041a\u043e\u043a",
  "\u041a\u043e\u043c\u0430\u043d\u0434\u0438\u0440",
  "\u041a\u043e\u043c\u0431\u0430\u0439\u043d\u0435\u0440",
  "\u041a\u043e\u043c\u0435\u043d\u0434\u0430\u043d\u0442",
  "\u041a\u043e\u043c\u043c\u0435\u0440\u0447\u0435\u0441\u043a\u0438\u0439 \u0434\u0438\u0440\u0435\u043a\u0442\u043e\u0440",
  "\u041a\u043e\u043c\u043f\u043e\u0437\u0438\u0442\u043e\u0440",
  "\u041a\u043e\u043d\u0432\u043e\u0438\u0440",
  "\u041a\u043e\u043d\u0434\u0438\u0442\u0435\u0440",
  "\u041a\u043e\u043d\u0434\u0438\u0442\u0435\u0440",
  "\u041a\u043e\u043d\u0434\u0443\u043a\u0442\u043e\u0440",
  "\u041a\u043e\u043d\u0435\u0432\u043e\u0434",
  "\u041a\u043e\u043d\u0442\u0435\u043d\u0442-\u043c\u0435\u043d\u0435\u0434\u0436\u0435\u0440",
  "\u041a\u043e\u043f\u0438\u0440\u0430\u0439\u0442\u0435\u0440",
  "\u041a\u043e\u0440\u0440\u0435\u043a\u0442\u0438\u0440\u043e\u0432\u0449\u0438\u043a",
  "\u041a\u043e\u0440\u0440\u0435\u043a\u0442\u043e\u0440",
  "\u041a\u043e\u0441\u043c\u0435\u0442\u043e\u043b\u043e\u0433",
  "\u041a\u043e\u0441\u043c\u043e\u043d\u0430\u0432\u0442",
  "\u041a\u0440\u0430\u043d\u043e\u0432\u0449\u0438\u043a",
  "\u041a\u0440\u0435\u0434\u0438\u0442\u043d\u044b\u0439 \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u043d\u0442",
  "\u041a\u0440\u0438\u043f\u0442\u043e\u0437\u043e\u043e\u043b\u043e\u0433",
  "\u041a\u0440\u0438\u0442\u0438\u043a",
  "\u041a\u0440\u043e\u0432\u0435\u043b\u044c\u0449\u0438\u043a",
  "\u041a\u0440\u043e\u043c\u043a\u043e\u0437\u0430\u043a\u0430\u0442\u0447\u0438\u043a",
  "\u041a\u0440\u0443\u043f\u044c\u0435",
  "\u041a\u0443\u0437\u043d\u0435\u0446",
  "\u041a\u0443\u043b\u044c\u0442\u0443\u0440\u043e\u043b\u043e\u0433",
  "\u041b\u0430\u0431\u043e\u0440\u0430\u043d\u0442",
  "\u041b\u0435\u043a\u0430\u043b\u044c\u0449\u0438\u043a",
  "\u041b\u0438\u043c\u0444\u043e\u043b\u043e\u0433",
  "\u041b\u0438\u043d\u0433\u0432\u0438\u0441\u0442",
  "\u041b\u0438\u0442\u0435\u0439\u0449\u0438\u043a",
  "\u041b\u0438\u0444\u0442\u0451\u0440",
  "\u041b\u043e\u0433\u0438\u043a",
  "\u041b\u043e\u0433\u043e\u043f\u0435\u0434",
  "\u041b\u043e\u0433\u043e\u043f\u0435\u0434",
  "\u041b\u043e\u0446\u043c\u0430\u043d",
  "\u041b\u0451\u0442\u0447\u0438\u043a",
  "\u041b\u0451\u0442\u0447\u0438\u043a",
  "\u041c\u0430\u043a\u043b\u0435\u0440 \u0431\u0438\u0440\u0436\u0435\u0432\u043e\u0439",
  "\u041c\u0430\u043b\u044f\u0440",
  "\u041c\u0430\u043c\u043c\u043e\u043b\u043e\u0433",
  "\u041c\u0430\u043d\u0435\u043a\u0435\u043d\u0449\u0438\u0446\u0430",
  "\u041c\u0430\u043d\u0443\u0430\u043b\u0438\u0441\u0442",
  "\u041c\u0430\u0440\u043a\u0435\u0442\u043e\u043b\u043e\u0433",
  "\u041c\u0430\u0440\u043a\u0438\u0442\u0430\u043d\u0442",
  "\u041c\u0430\u0440\u043a\u0448\u0435\u0439\u0434\u0435\u0440",
  "\u041c\u0430\u0441\u0441\u0430\u0436\u0438\u0441\u0442",
  "\u041c\u0430\u0441\u0442\u0435\u0440 \u043c\u0430\u043d\u0438\u043a\u044e\u0440\u0430",
  "\u041c\u0430\u0441\u0442\u0435\u0440 \u043c\u0430\u043d\u0438\u043a\u044e\u0440\u0430",
  "\u041c\u0430\u0441\u0442\u0435\u0440 \u043f\u0435\u0434\u0438\u043a\u044e\u0440\u0430",
  "\u041c\u0430\u0442\u0435\u043c\u0430\u0442\u0438\u043a",
  "\u041c\u0430\u0448\u0438\u043d\u0438\u0441\u0442",
  "\u041c\u0430\u0448\u0438\u043d\u0438\u0441\u0442 \u043b\u043e\u043a\u043e\u043c\u043e\u0442\u0438\u0432\u0430",
  "\u041c\u0430\u0448\u0438\u043d\u0438\u0441\u0442\u043a\u0430",
  "\u041c\u0435\u0434\u0438\u0446\u0438\u043d\u0441\u043a\u0430\u044f \u0441\u0435\u0441\u0442\u0440\u0430",
  "\u041c\u0435\u0434\u043d\u0438\u043a",
  "\u041c\u0435\u043b\u0438\u043e\u0440\u0430\u0442\u043e\u0440",
  "\u041c\u0435\u043b\u044c\u043d\u0438\u043a",
  "\u041c\u0435\u043d\u0435\u0434\u0436\u0435\u0440",
  "\u041c\u0435\u043d\u0435\u0434\u0436\u0435\u0440 \u043f\u043e \u0440\u0430\u0431\u043e\u0442\u0435 \u0441 \u043a\u043b\u0438\u0435\u043d\u0442\u0430\u043c\u0438",
  "\u041c\u0435\u0440\u0447\u0430\u043d\u0434\u0430\u0439\u0437\u0435\u0440",
  "\u041c\u0435\u0441\u0438\u043b\u044c\u0449\u0438\u043a",
  "\u041c\u0435\u0442\u0430\u043b\u043b\u0443\u0440\u0433",
  "\u041c\u0435\u0442\u0435\u043e\u0440\u043e\u043b\u043e\u0433",
  "\u041c\u0435\u0442\u0440\u0430\u043d\u043f\u0430\u0436",
  "\u041c\u0435\u0442\u0440\u0434\u043e\u0442\u0435\u043b\u044c",
  "\u041c\u0435\u0445\u0430\u043d\u0438\u0437\u0430\u0442\u043e\u0440",
  "\u041c\u0435\u0445\u0430\u043d\u0438\u043a",
  "\u041c\u0435\u0445\u0430\u043d\u0438\u043a-\u0412\u043e\u0434\u0438\u0442\u0435\u043b\u044c",
  "\u041c\u0438\u043a\u043e\u043b\u043e\u0433",
  "\u041c\u0438\u043a\u0440\u043e\u0431\u0438\u043e\u043b\u043e\u0433",
  "\u041c\u0438\u043d\u0438\u0441\u0442\u0440",
  "\u041c\u043e\u0434\u0435\u043b\u044c",
  "\u041c\u043e\u0434\u0435\u043b\u044c\u0435\u0440",
  "\u041c\u043e\u043d\u0442\u0430\u0436\u043d\u0438\u043a",
  "\u041c\u043e\u043d\u0442\u0430\u0436\u043d\u0438\u043a \u0440\u0430\u0434\u0438\u043e\u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u0430\u043f\u043f\u0430\u0440\u0430\u0442\u0443\u0440\u044b \u0438 \u043f\u0440\u0438\u0431\u043e\u0440\u043e\u0432",
  "\u041c\u043e\u043d\u0442\u0430\u0436\u043d\u0438\u043a \u0441\u0432\u044f\u0437\u0438",
  "\u041c\u043e\u0440\u0441\u043a\u043e\u0439 \u043f\u0435\u0445\u043e\u0442\u0438\u043d\u0435\u0446",
  "\u041c\u043e\u0442\u043e\u0440\u0438\u0441\u0442",
  "\u041c\u043e\u0442\u043e\u0440\u0438\u0441\u0442",
  "\u041c\u043e\u0442\u043e\u0441\u0442\u0440\u0435\u043b\u043e\u043a",
  "\u041c\u0443\u0437\u044b\u043a\u0430\u043d\u0442",
  "\u041c\u0443\u0441\u043e\u0440\u043e\u043f\u0440\u043e\u0432\u043e\u0434\u0447\u0438\u043a",
  "\u041c\u0443\u0441\u043e\u0440\u0449\u0438\u043a",
  "\u041c\u044f\u0441\u043d\u0438\u043a",
  "\u041d\u0430\u0432\u043e\u0434\u0447\u0438\u043a \u043e\u0440\u0443\u0434\u0438\u044f",
  "\u041d\u0430\u043b\u043e\u0433\u043e\u0432\u044b\u0439 \u0438\u043d\u0441\u043f\u0435\u043a\u0442\u043e\u0440",
  "\u041d\u0430\u0440\u043a\u043e\u043b\u043e\u0433",
  "\u041d\u0430\u0447\u0430\u043b\u044c\u043d\u0438\u043a \u0432\u043e\u0435\u043d\u043d\u043e\u0433\u043e \u043e\u0440\u043a\u0435\u0441\u0442\u0440\u0430",
  "\u041d\u0430\u0447\u0430\u043b\u044c\u043d\u0438\u043a \u0433\u0430\u0443\u043f\u0432\u0430\u0445\u0442\u044b",
  "\u041d\u0430\u0447\u0430\u043b\u044c\u043d\u0438\u043a \u0441\u043a\u043b\u0430\u0434\u0430",
  "\u041d\u0430\u0447\u0430\u043b\u044c\u043d\u0438\u043a \u0441\u043b\u0443\u0436\u0431\u044b",
  "\u041d\u0430\u0447\u0430\u043b\u044c\u043d\u0438\u043a \u0448\u0442\u0430\u0431\u0430",
  "\u041d\u0435\u0432\u0440\u043e\u043b\u043e\u0433",
  "\u041d\u0435\u0432\u0440\u043e\u043f\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u041d\u0435\u0439\u0440\u043e\u0445\u0438\u0440\u0443\u0440\u0433",
  "\u041d\u0435\u043e\u043d\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u041d\u0435\u0444\u0440\u043e\u043b\u043e\u0433",
  "\u041d\u043e\u0442\u0430\u0440\u0438\u0443\u0441",
  "\u041d\u044f\u043d\u044f",
  "\u041e\u0433\u043d\u0435\u043c\u0451\u0442\u0447\u0438\u043a",
  "\u041e\u043a\u0435\u0430\u043d\u043e\u043b\u043e\u0433",
  "\u041e\u043d\u043a\u043e\u043b\u043e\u0433",
  "\u041e\u043f\u0435\u0440\u0430\u0442\u0438\u0432\u043d\u044b\u0439 \u0440\u0430\u0431\u043e\u0442\u043d\u0438\u043a",
  "\u041e\u043f\u0435\u0440\u0430\u0442\u043e\u0440 \u041f\u041a",
  "\u041e\u043f\u0435\u0440\u0430\u0442\u043e\u0440 \u0420\u041b\u0421",
  "\u041e\u043f\u0435\u0440\u0430\u0442\u043e\u0440 \u0432\u043e\u043e\u0440\u0443\u0436\u0435\u043d\u0438\u044f",
  "\u041e\u043f\u0435\u0440\u0430\u0442\u043e\u0440 \u043a\u0438\u043d\u043e \u0438 \u0442\u0435\u043b\u0435\u0432\u0438\u0434\u0435\u043d\u0438\u044f",
  "\u041e\u043f\u0435\u0440\u0430\u0442\u043e\u0440 \u043a\u043e\u043b\u043b\u0446\u0435\u043d\u0442\u0440\u0430",
  "\u041e\u043f\u0435\u0440\u0430\u0442\u043e\u0440 \u043c\u0430\u0448\u0438\u043d\u043d\u043e\u0433\u043e \u0434\u043e\u0435\u043d\u0438\u044f",
  "\u041e\u043f\u0435\u0440\u0430\u0446\u0438\u043e\u043d\u0438\u0441\u0442",
  "\u041e\u0440\u0433\u0430\u043d\u0438\u0437\u0430\u0442\u043e\u0440 \u0441\u0432\u0430\u0434\u0435\u0431",
  "\u041e\u0440\u043d\u0438\u0442\u043e\u043b\u043e\u0433",
  "\u041e\u0440\u0442\u043e\u0434\u043e\u043d\u0442",
  "\u041e\u0440\u0442\u043e\u043f\u0435\u0434",
  "\u041e\u0441\u043e\u0431\u0438\u0441\u0442",
  "\u041e\u0442\u043e\u0440\u0438\u043d\u043e\u043b\u0430\u0440\u0438\u043d\u0433\u043e\u043b\u043e\u0433",
  "\u041e\u0444\u0438\u0446\u0438\u0430\u043d\u0442",
  "\u041e\u0444\u0442\u0430\u043b\u044c\u043c\u043e\u043b\u043e\u0433",
  "\u041f\u0430\u043b\u0435\u043e\u043d\u0442\u043e\u043b\u043e\u0433",
  "\u041f\u0430\u0440\u0438\u043a\u043c\u0430\u0445\u0435\u0440",
  "\u041f\u0430\u0440\u0438\u043a\u043c\u0430\u0445\u0435\u0440",
  "\u041f\u0430\u0440\u0444\u044e\u043c\u0435\u0440",
  "\u041f\u0430\u0441\u0442\u0443\u0445",
  "\u041f\u0430\u0442\u043e\u043b\u043e\u0433\u043e\u0430\u043d\u0430\u0442\u043e\u043c",
  "\u041f\u0435\u0434\u0430\u0433\u043e\u0433",
  "\u041f\u0435\u0434\u0438\u0430\u0442\u0440",
  "\u041f\u0435\u043a\u0430\u0440\u044c",
  "\u041f\u0435\u0440\u0435\u0432\u043e\u0434\u0447\u0438\u043a",
  "\u041f\u0435\u0440\u0435\u0432\u043e\u0434\u0447\u0438\u043a",
  "\u041f\u0435\u0440\u0435\u043f\u043b\u0451\u0442\u0447\u0438\u043a",
  "\u041f\u0435\u0447\u0430\u0442\u043d\u0438\u043a",
  "\u041f\u0438\u0441\u0430\u0442\u0435\u043b\u044c",
  "\u041f\u043b\u0430\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0439 \u0445\u0438\u0440\u0443\u0440\u0433",
  "\u041f\u043b\u0438\u0442\u043e\u0447\u043d\u0438\u043a",
  "\u041f\u043b\u043e\u0442\u043d\u0438\u043a",
  "\u041f\u043e\u0432\u0430\u0440",
  "\u041f\u043e\u0432\u0430\u0440",
  "\u041f\u043e\u0433\u0440\u0430\u043d\u0438\u0447\u043d\u0438\u043a",
  "\u041f\u043e\u0434\u0432\u043e\u0434\u043d\u0438\u043a",
  "\u041f\u043e\u0436\u0430\u0440\u043d\u044b\u0439",
  "\u041f\u043e\u043b\u0438\u0442\u043e\u043b\u043e\u0433",
  "\u041f\u043e\u043b\u0438\u0446\u0435\u0439\u0441\u043a\u0438\u0439",
  "\u041f\u043e\u0440\u0442\u043d\u043e\u0439",
  "\u041f\u043e\u0440\u0442\u044c\u0435",
  "\u041f\u043e\u0441\u0442\u0430\u043d\u043e\u0432\u0449\u0438\u043a \u0442\u0440\u044e\u043a\u043e\u0432",
  "\u041f\u043e\u0447\u0442\u0430\u043b\u044c\u043e\u043d",
  "\u041f\u043e\u044d\u0442",
  "\u041f\u0440\u0430\u0432\u043e\u0432\u0435\u0434",
  "\u041f\u0440\u0435\u0434\u043f\u0440\u0438\u043d\u0438\u043c\u0430\u0442\u0435\u043b\u044c",
  "\u041f\u0440\u0435\u043f\u043e\u0434\u0430\u0432\u0430\u0442\u0435\u043b\u044c",
  "\u041f\u0440\u043e\u0432\u043e\u0434\u043d\u0438\u043a",
  "\u041f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0438\u0441\u0442",
  "\u041f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0438\u0441\u0442",
  "\u041f\u0440\u043e\u0434\u0430\u0432\u0435\u0446",
  "\u041f\u0440\u043e\u0434\u0430\u0432\u0435\u0446",
  "\u041f\u0440\u043e\u0434\u044e\u0441\u0435\u0440",
  "\u041f\u0440\u043e\u0437\u0435\u043a\u0442\u043e\u0440",
  "\u041f\u0440\u043e\u043a\u0442\u043e\u043b\u043e\u0433",
  "\u041f\u0440\u043e\u043a\u0443\u0440\u043e\u0440",
  "\u041f\u0440\u043e\u043c\u044b\u0448\u043b\u0435\u043d\u043d\u044b\u0439 \u0430\u043b\u044c\u043f\u0438\u043d\u0438\u0441\u0442",
  "\u041f\u0440\u043e\u043c\u044b\u0448\u043b\u0435\u043d\u043d\u044b\u0439 \u0430\u043b\u044c\u043f\u0438\u043d\u0438\u0441\u0442",
  "\u041f\u0440\u043e\u0440\u0435\u043a\u0442\u043e\u0440",
  "\u041f\u0440\u043e\u0444\u043f\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u041f\u0440\u043e\u0445\u043e\u0434\u0447\u0438\u043a",
  "\u041f\u0441\u0438\u0445\u0438\u0430\u0442\u0440",
  "\u041f\u0441\u0438\u0445\u043e\u043b\u043e\u0433",
  "\u041f\u0441\u0438\u0445\u043e\u043d\u0435\u0432\u0440\u043e\u043f\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u041f\u0441\u0438\u0445\u043e\u0442\u0435\u0440\u0430\u043f\u0435\u0432\u0442",
  "\u041f\u0443\u043b\u0435\u043c\u0451\u0442\u0447\u0438\u043a",
  "\u041f\u0443\u043b\u044c\u043c\u043e\u043d\u043e\u043b\u043e\u0433",
  "\u041f\u0447\u0435\u043b\u043e\u0432\u043e\u0434",
  "\u0420\u0430\u0431\u043e\u0442\u043d\u0438\u043a \u043e\u0440\u0433\u0430\u043d\u043e\u0432 \u0417\u0410\u0413\u0421\u0430",
  "\u0420\u0430\u0434\u0438\u043e\u043b\u043e\u0433",
  "\u0420\u0430\u0434\u0438\u043e\u043c\u0435\u0445\u0430\u043d\u0438\u043a",
  "\u0420\u0430\u0434\u0438\u043e\u0442\u0435\u043b\u0435\u0444\u043e\u043d\u0438\u0441\u0442",
  "\u0420\u0430\u0434\u0438\u0441\u0442",
  "\u0420\u0430\u0434\u0438\u0441\u0442",
  "\u0420\u0430\u0437\u0432\u0435\u0434\u0447\u0438\u043a",
  "\u0420\u0430\u043a\u0435\u0442\u0447\u0438\u043a",
  "\u0420\u0430\u0441\u043f\u0438\u043b\u043e\u0432\u0449\u0438\u043a",
  "\u0420\u0430\u0441\u0442\u0435\u043d\u0438\u0435\u0432\u043e\u0434",
  "\u0420\u0430\u0441\u0442\u043e\u0447\u043d\u0438\u043a",
  "\u0420\u0435\u0430\u043d\u0438\u043c\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0420\u0435\u0432\u043c\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0420\u0435\u0434\u0430\u043a\u0442\u043e\u0440",
  "\u0420\u0435\u0436\u0438\u0441\u0441\u0451\u0440",
  "\u0420\u0435\u043a\u0442\u043e\u0440",
  "\u0420\u0435\u043b\u0430\u0439\u0442\u0435\u0440",
  "\u0420\u0435\u043b\u0438\u0433\u0438\u043e\u0432\u0435\u0434",
  "\u0420\u0435\u043d\u0442\u0433\u0435\u043d\u043e\u043b\u043e\u0433",
  "\u0420\u0435\u0441\u0442\u0430\u0432\u0440\u0430\u0442\u043e\u0440",
  "\u0420\u0435\u0444\u043b\u0435\u043a\u0441\u043e\u0442\u0435\u0440\u0430\u043f\u0435\u0432\u0442",
  "\u0420\u0438\u0445\u0442\u043e\u0432\u0449\u0438\u043a",
  "\u0420\u043e\u0431\u043e\u0442\u043e\u0442\u0435\u0445\u043d\u0438\u043a",
  "\u0421\u0430\u0434\u043e\u0432\u043d\u0438\u043a",
  "\u0421\u0430\u0434\u043e\u0432\u043e\u0434",
  "\u0421\u0430\u043d\u0438\u0442\u0430\u0440",
  "\u0421\u0430\u043d\u0442\u0435\u0445\u043d\u0438\u043a",
  "\u0421\u0430\u043f\u043e\u0436\u043d\u0438\u043a",
  "\u0421\u0430\u043f\u0451\u0440",
  "\u0421\u0431\u043e\u0440\u0449\u0438\u043a",
  "\u0421\u0432\u0430\u0440\u0449\u0438\u043a",
  "\u0421\u0432\u044f\u0437\u0438\u0441\u0442",
  "\u0421\u0432\u044f\u0449\u0435\u043d\u043d\u043e\u0441\u043b\u0443\u0436\u0438\u0442\u0435\u043b\u044c",
  "\u0421\u0435\u043a\u0440\u0435\u0442\u0447\u0438\u043a",
  "\u0421\u0435\u043a\u0441\u043e\u043b\u043e\u0433",
  "\u0421\u0435\u043a\u0441\u043e\u043f\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0421\u0435\u043c\u0435\u0439\u043d\u044b\u0439 \u0432\u0440\u0430\u0447",
  "\u0421\u0435\u0440\u043f\u0435\u043d\u0442\u043e\u043b\u043e\u0433",
  "\u0421\u0438\u0434\u0435\u043b\u043a\u0430",
  "\u0421\u0438\u0441\u0442\u0435\u043c\u043d\u044b\u0439 \u0430\u0434\u043c\u0438\u043d\u0438\u0441\u0442\u0440\u0430\u0442\u043e\u0440",
  "\u0421\u043a\u043e\u0440\u043d\u044f\u043a",
  "\u0421\u043a\u043e\u0442\u043d\u0438\u043a",
  "\u0421\u043a\u0443\u043b\u044c\u043f\u0442\u043e\u0440",
  "\u0421\u043b\u0435\u0434\u043e\u0432\u0430\u0442\u0435\u043b\u044c",
  "\u0421\u043b\u0435\u0441\u0430\u0440\u044c",
  "\u0421\u043b\u0435\u0441\u0430\u0440\u044c-\u043c\u0435\u0445\u0430\u043d\u0438\u043a",
  "\u0421\u043c\u0435\u0442\u0447\u0438\u043a",
  "\u0421\u043d\u0430\u0431\u0436\u0435\u043d\u0435\u0446",
  "\u0421\u043d\u0430\u0439\u043f\u0435\u0440",
  "\u0421\u043e\u043c\u0435\u043b\u044c\u0435",
  "\u0421\u043e\u043c\u043d\u043e\u043b\u043e\u0433",
  "\u0421\u043e\u0446\u0438\u043e\u043b\u043e\u0433",
  "\u0421\u043f\u0435\u0446\u0438\u0430\u043b\u0438\u0441\u0442 \u043f\u043e \u043a\u043b\u0435\u0442\u043e\u0447\u043d\u044b\u043c \u0442\u0435\u0445\u043d\u043e\u043b\u043e\u0433\u0438\u044f\u043c",
  "\u0421\u043f\u0435\u0446\u0438\u0430\u043b\u0438\u0441\u0442 \u043f\u043e \u0441\u0442\u0440\u0438\u0436\u043a\u0435 \u043e\u0432\u0435\u0446",
  "\u0421\u043f\u043e\u0440\u0442\u0438\u0432\u043d\u044b\u0439 \u0432\u0440\u0430\u0447",
  "\u0421\u0442\u0430\u043b\u0435\u0432\u0430\u0440",
  "\u0421\u0442\u0430\u0440\u0448\u0438\u043d\u0430",
  "\u0421\u0442\u0438\u043b\u0438\u0441\u0442",
  "\u0421\u0442\u043e\u043b\u044f\u0440",
  "\u0421\u0442\u043e\u043b\u044f\u0440-\u043a\u0440\u0430\u0441\u043d\u043e\u0434\u0435\u0440\u0435\u0432\u0449\u0438\u043a",
  "\u0421\u0442\u043e\u043c\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0421\u0442\u0440\u0430\u0445\u043e\u0432\u043e\u0439 \u0430\u0433\u0435\u043d\u0442",
  "\u0421\u0442\u0440\u0435\u043b\u043e\u043a",
  "\u0421\u0442\u0440\u0435\u043b\u043e\u0447\u043d\u0438\u043a",
  "\u0421\u0442\u0440\u043e\u0438\u0442\u0435\u043b\u044c",
  "\u0421\u0443\u0434\u0435\u0431\u043d\u044b\u0439 \u043f\u0440\u0438\u0441\u0442\u0430\u0432",
  "\u0421\u0443\u0434\u044c\u044f",
  "\u0421\u0443\u0440\u0434\u043e\u043b\u043e\u0433",
  "\u0421\u0443\u0440\u0434\u043e\u043f\u0435\u0434\u0430\u0433\u043e\u0433",
  "\u0421\u0446\u0435\u043d\u0430\u0440\u0438\u0441\u0442",
  "\u0421\u044b\u0440\u043e\u0432\u0430\u0440",
  "\u0422\u0430\u0431\u0430\u043a\u043e\u0432\u043e\u0434",
  "\u0422\u0430\u0431\u0443\u043d\u0449\u0438\u043a",
  "\u0422\u0430\u043a\u0441\u0438\u0441\u0442",
  "\u0422\u0430\u043b\u044c\u043c\u0430\u043d",
  "\u0422\u0430\u043c\u043e\u0436\u0435\u043d\u043d\u0438\u043a",
  "\u0422\u0430\u043d\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0422\u0430\u043d\u043a\u0438\u0441\u0442",
  "\u0422\u0430\u043d\u0446\u043e\u0440",
  "\u0422\u0430\u0442\u0443\u0438\u0440\u043e\u0432\u0449\u0438\u043a",
  "\u0422\u0435\u043b\u0435\u0433\u0440\u0430\u0444\u0438\u0441\u0442",
  "\u0422\u0435\u043b\u0435\u0436\u0443\u0440\u043d\u0430\u043b\u0438\u0441\u0442",
  "\u0422\u0435\u043b\u0435\u043c\u0430\u0441\u0442\u0435\u0440",
  "\u0422\u0435\u043b\u0435\u0444\u043e\u043d\u0438\u0441\u0442",
  "\u0422\u0435\u043b\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u0435\u043b\u044c",
  "\u0422\u0435\u043e\u043b\u043e\u0433",
  "\u0422\u0435\u0440\u0430\u043f\u0435\u0432\u0442",
  "\u0422\u0435\u0440\u0438\u043e\u043b\u043e\u0433",
  "\u0422\u0435\u0441\u0442\u0438\u0440\u043e\u0432\u0449\u0438\u043a",
  "\u0422\u0435\u0445\u043d\u0438\u043a",
  "\u0422\u0435\u0445\u043d\u0438\u043a",
  "\u0422\u0435\u0445\u043d\u043e\u043b\u043e\u0433",
  "\u0422\u0438\u043f\u043e\u0433\u0440\u0430\u0444",
  "\u0422\u0438\u0444\u043b\u043e\u043f\u0435\u0434\u0430\u0433\u043e\u0433",
  "\u0422\u043e\u0432\u0430\u0440\u043e\u0432\u0435\u0434",
  "\u0422\u043e\u043a\u0430\u0440\u044c",
  "\u0422\u043e\u043a\u0430\u0440\u044c-\u043a\u0430\u0440\u0443\u0441\u0435\u043b\u044c\u0449\u0438\u043a",
  "\u0422\u043e\u043a\u0441\u0438\u043a\u043e\u043b\u043e\u0433",
  "\u0422\u043e\u043f\u043e\u0433\u0440\u0430\u0444",
  "\u0422\u043e\u0440\u0430\u043a\u0430\u043b\u044c\u043d\u044b\u0439 \u0445\u0438\u0440\u0443\u0440\u0433",
  "\u0422\u043e\u0440\u0433\u043e\u0432\u044b\u0439 \u043f\u0440\u0435\u0434\u0441\u0442\u0430\u0432\u0438\u0442\u0435\u043b\u044c",
  "\u0422\u0440\u0430\u0432\u043c\u0430\u0442\u043e\u043b\u043e\u0433",
  "\u0422\u0440\u0430\u043a\u0442\u043e\u0440\u0438\u0441\u0442",
  "\u0422\u0440\u0430\u043d\u0441\u0444\u0443\u0437\u0438\u043e\u043b\u043e\u0433",
  "\u0422\u0440\u0435\u0439\u0434\u0435\u0440",
  "\u0422\u0440\u0435\u043d\u0434-\u0432\u043e\u0442\u0447\u0435\u0440",
  "\u0422\u044b\u043b\u043e\u0432\u0438\u043a",
  "\u0422\u044e\u0440\u0435\u043c\u043d\u044b\u0439 \u043d\u0430\u0434\u0437\u0438\u0440\u0430\u0442\u0435\u043b\u044c",
  "\u0423\u0431\u043e\u0440\u0449\u0438\u043a",
  "\u0423\u043f\u0430\u043a\u043e\u0432\u0449\u0438\u043a",
  "\u0423\u0440\u043e\u043b\u043e\u0433",
  "\u0423\u0447\u0438\u0442\u0435\u043b\u044c",
  "\u0423\u0447\u0451\u043d\u044b\u0439",
  "\u0424\u0430\u043b\u044c\u0446\u043e\u0432\u0449\u0438\u043a",
  "\u0424\u0430\u0440\u043c\u0430\u0446\u0435\u0432\u0442",
  "\u0424\u0435\u043b\u044c\u0434\u0448\u0435\u0440",
  "\u0424\u0435\u043b\u044c\u0434\u0448\u0435\u0440",
  "\u0424\u0435\u0440\u043c\u0435\u0440",
  "\u0424\u0438\u0437\u0438\u043a",
  "\u0424\u0438\u0437\u0438\u043e\u0442\u0435\u0440\u0430\u043f\u0435\u0432\u0442",
  "\u0424\u0438\u043b\u043e\u043b\u043e\u0433",
  "\u0424\u0438\u043b\u043e\u0441\u043e\u0444",
  "\u0424\u0438\u043d\u0430\u043d\u0441\u0438\u0441\u0442",
  "\u0424\u0438\u043d\u0430\u043d\u0441\u0438\u0441\u0442",
  "\u0424\u043b\u0435\u0431\u043e\u043b\u043e\u0433",
  "\u0424\u043b\u043e\u0440\u0438\u0441\u0442",
  "\u0424\u043b\u043e\u0440\u0438\u0441\u0442",
  "\u0424\u043e\u0440\u043c\u043e\u0432\u0449\u0438\u043a",
  "\u0424\u043e\u0440\u0442\u0438\u0444\u0438\u043a\u0430\u0442\u043e\u0440",
  "\u0424\u043e\u0442\u043e\u0433\u0440\u0430\u0444",
  "\u0424\u043e\u0442\u043e\u043c\u043e\u0434\u0435\u043b\u044c",
  "\u0424\u0440\u0435\u0437\u0435\u0440\u043e\u0432\u0449\u0438\u043a",
  "\u0424\u0442\u0438\u0437\u0438\u0430\u0442\u0440",
  "\u0424\u0443\u0440\u0430\u0436\u0438\u0440",
  "\u0424\u0443\u0442\u0443\u0440\u043e\u043b\u043e\u0433",
  "\u0425\u0438\u043c\u0438\u043a",
  "\u0425\u0438\u043c\u0438\u043a",
  "\u0425\u0438\u043c\u0438\u043a-\u0430\u043d\u0430\u043b\u0438\u0442\u0438\u043a",
  "\u0425\u0438\u043c\u0438\u043a-\u043a\u043e\u043d\u0442\u0440\u043e\u043b\u0435\u0440",
  "\u0425\u0438\u043c\u0438\u043a-\u0442\u0435\u0445\u043d\u043e\u043b\u043e\u0433",
  "\u0425\u0438\u0440\u0443\u0440\u0433",
  "\u0425\u043b\u0435\u0431\u043e\u043f\u0451\u043a",
  "\u0425\u043b\u0435\u0431\u043e\u0440\u043e\u0431",
  "\u0425\u043b\u043e\u043f\u043e\u043a\u043e\u0440\u043e\u0431",
  "\u0425\u043e\u043b\u043e\u0434\u0438\u043b\u044c\u0449\u0438\u043a",
  "\u0425\u043e\u0440\u0435\u043e\u0433\u0440\u0430\u0444",
  "\u0425\u0443\u0434\u043e\u0436\u043d\u0438\u043a",
  "\u0425\u0443\u0434\u043e\u0436\u043d\u0438\u043a \u043f\u043e \u0441\u0432\u0435\u0442\u0443",
  "\u0428\u0430\u0445\u0442\u0451\u0440",
  "\u0428\u0432\u0435\u0439\u0446\u0430\u0440",
  "\u0428\u0432\u0435\u044f",
  "\u0428\u0438\u0444\u0440\u043e\u0432\u0430\u043b\u044c\u0449\u0438\u043a",
  "\u0428\u043a\u0438\u043f\u0435\u0440",
  "\u0428\u043b\u0438\u0444\u043e\u0432\u0449\u0438\u043a",
  "\u0428\u043e\u0440\u043d\u0438\u043a",
  "\u0428\u0442\u0443\u043a\u0430\u0442\u0443\u0440",
  "\u0428\u0442\u0443\u0440\u043c\u0430\u043d",
  "\u042d\u043a\u043e\u043b\u043e\u0433",
  "\u042d\u043a\u043e\u043d\u043e\u043c\u0438\u0441\u0442",
  "\u042d\u043a\u0441\u043f\u0435\u0434\u0438\u0442\u043e\u0440",
  "\u042d\u043a\u0441\u043f\u0435\u0434\u0438\u0442\u043e\u0440 \u043d\u0430 \u0434\u0430\u043b\u044c\u043d\u0438\u0445 \u043f\u043e\u0435\u0437\u0434\u043a\u0430\u0445",
  "\u042d\u043a\u0441\u043f\u0435\u0440\u0442-\u043a\u0440\u0438\u043c\u0438\u043d\u0430\u043b\u0438\u0441\u0442",
  "\u042d\u043b\u0435\u043a\u0442\u0440\u0438\u043a",
  "\u042d\u043d\u0434\u043e\u043a\u0440\u0438\u043d\u043e\u043b\u043e\u0433",
  "\u042d\u043d\u0434\u043e\u0441\u043a\u043e\u043f\u0438\u0441\u0442",
  "\u042d\u043d\u0442\u043e\u043c\u043e\u043b\u043e\u0433",
  "\u042d\u043f\u0438\u0434\u0435\u043c\u0438\u043e\u043b\u043e\u0433",
  "\u042d\u0444\u0444\u0435\u0440\u0435\u043d\u0442\u043e\u043b\u043e\u0433",
  "\u042e\u0432\u0435\u043b\u0438\u0440",
  "\u042e\u0440\u0438\u0441\u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442",
  "\u042e\u0440\u0438\u0441\u0442"
)

#' Job provider for Russia
#'
#' @inherit JobProvider description details return
#' @family ru
#' @family RU
#' @export
#' @examples
#' x <- JobProvider_ru_RU$new()
#' x$render()
JobProvider_ru_RU <- R6::R6Class(
  inherit = JobProvider,
  "JobProvider_ru_RU",
  private = list(
    locale_ = "ru_RU",
    formats = job_formats_ru_ru
  )
)
